@@ -1,7 +1,7 @@
 """Scrapy scrapers for each on-line database."""
 
 # The version of the JSON data structure used to represent the checklist.
-CHECKLISTS_DOWNLOAD_FORMAT = 1
+DOWNLOAD_FORMAT = 1
 
 # The default ISO 639-1 Code for the language used in the file.
-CHECKLISTS_DOWNLOAD_LANGUAGE = 'en'
+DOWNLOAD_LANGUAGE = 'en'
